]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - fs.h
csqc packet log code (for entityframedatabase 5 only, i.e. DP5 and higher)
[xonotic/darkplaces.git] / fs.h
diff --git a/fs.h b/fs.h
index 9ed0b5114cf2c22c236758cf586f9221634f8ce0..cf2290fa87e70688eebd10dcb7663d3032aa4efd 100644 (file)
--- a/fs.h
+++ b/fs.h
@@ -31,8 +31,8 @@
 typedef struct qfile_s qfile_t;
 
 #ifdef WIN32
-typedef long fs_offset_t; // 32bit
-//typedef _int64 fs_offset_t; // 64bit (lots of warnings, and lseek/read/write still don't take 64bit on win64)
+//typedef long fs_offset_t; // 32bit
+typedef __int64 fs_offset_t; // 64bit (lots of warnings, and read/write still don't take 64bit on win64)
 #else
 typedef long long fs_offset_t;
 #endif
@@ -53,11 +53,12 @@ extern char fs_gamedirs[MAX_GAMEDIRS][MAX_QPATH];
 // ------ Main functions ------ //
 
 // IMPORTANT: the file path is automatically prefixed by the current game directory for
// each file created by FS_WriteFile, or opened in "write" or "append" mode by FS_Open
 
 qboolean FS_AddPack(const char *pakfile, qboolean *already_loaded, qboolean keep_plain_dirs); // already_loaded may be NULL if caller does not care
 const char *FS_WhichPack(const char *filename);
-qfile_t *FS_Open (const char* filepath, const char* mode, qboolean quiet, qboolean nonblocking);
+qfile_t* FS_OpenRealFile (const char* filepath, const char* mode, qboolean quiet);
+qfile_t* FS_OpenVirtualFile (const char* filepath, qboolean quiet);
 int FS_Close (qfile_t* file);
 fs_offset_t FS_Write (qfile_t* file, const void* data, size_t datasize);
 fs_offset_t FS_Read (qfile_t* file, void* buffer, size_t buffersize);
@@ -100,6 +101,12 @@ qboolean FS_WriteFile (const char *filename, void *data, fs_offset_t len);
 void FS_StripExtension (const char *in, char *out, size_t size_out);
 void FS_DefaultExtension (char *path, const char *extension, size_t size_path);
 
+#define FS_FILETYPE_NONE 0
+#define FS_FILETYPE_FILE 1
+#define FS_FILETYPE_DIRECTORY 2
+int FS_FileType (const char *filename);                // the file can be into a package
+int FS_SysFileType (const char *filename);             // only look for files outside of packages
+
 qboolean FS_FileExists (const char *filename);         // the file can be into a package
 qboolean FS_SysFileExists (const char *filename);      // only look for files outside of packages
@@ -53,11 +53,12 @@ extern char fs_gamedirs[MAX_GAMEDIRS][MAX_QPATH];
 
 // IMPORTANT: the file path is automatically prefixed by the current game directory for
-// each file created by FS_WriteFile, or opened in "write" or "append" mode by FS_Open
+// each file created by FS_WriteFile, or opened in "write" or "append" mode by FS_OpenRealFile
 
 qboolean FS_AddPack(const char *pakfile, qboolean *already_loaded, qboolean keep_plain_dirs); // already_loaded may be NULL if caller does not care